Astronomical dust extinction
============================

This package provides astronomical interstellar dust extinction curves
implemented using the astropy.modeling framework.

This package is an `affiliated package <https://www.astropy.org/affiliated/>`_ of `AstroPy`_.

To install::

    pip install dust_extinction

Build checks/status
-------------------

.. image:: http://readthedocs.org/projects/dust-extinction/badge/?version=latest
   :target: http://dust-extinction.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/karllark/dust_extinction/workflows/Python%20Tests/badge.svg
   :target: https://github.com/karllark/dust_extinction/actions/
   :alt: Test Status

.. image:: https://codecov.io/gh/karllark/dust_extinction/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/karllark/dust_extinction
   :alt: Test Coverage Status

.. image:: https://app.codacy.com/project/badge/Grade/748429f338714270bb5fffd87a0183b5
   :target: https://app.codacy.com/gh/karllark/dust_extinction/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade
   :alt: Codacy Status

Packaging
---------

.. image:: https://badge.fury.io/py/dust-extinction.svg
   :target: https://badge.fury.io/py/dust-extinction
   :alt: pypi dust_extinction

.. image:: https://anaconda.org/conda-forge/dust_extinction/badges/version.svg
   :target: https://github.com/conda-forge/dust_extinction-feedstock
   :alt: dust_extinction feedstock and install directions

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

Documentation
-------------

Using `readthedocs <http://dust-extinction.readthedocs.io>`_.

In Development!
---------------

This code is currently in active development.
Contributions welcome (see below).

Contributors
------------
Karl Gordon (lead)

`All contributors <https://github.com/karllark/dust_extinction/graphs/contributors>`_

Contributing
------------

Please open a new issue or new pull request for bugs, feedback, or new features
you would like to see.   If there is an issue you would like to work on, please
leave a comment and we will be happy to assist.   New contributions and
contributors are very welcome!

New to github or open source projects?  If you are unsure about where to start
or haven't used github before, please feel free to contact `@karllark`.
Want more information about how to make a contribution?  Take a look at
the astropy `contributing`_ and `developer`_ documentation.

Feedback and feature requests?   Is there something missing you would like
to see?  Please open an issue or send an email to  `@karllark`.
dust_extinction follows the `Astropy Code of Conduct`_ and strives to provide a
welcoming community to all of our users and contributors.

We love contributions! dust_extinction is open source,
built on open source, and we'd love to have you hang out in our community.

**Impostor syndrome disclaimer**: We want your help. No, really.

There may be a little voice inside your head that is telling you that you're not
ready to be an open source contributor; that your skills aren't nearly good
enough to contribute. What could you possibly offer a project like this one?

We assure you - the little voice in your head is wrong. If you can write code at
all, you can contribute code to open source. Contributing to open source
projects is a fantastic way to advance one's coding skills. Writing perfect code
isn't the measure of a good developer (that would disqualify all of us!); it's
trying to create something, making mistakes, and learning from those
mistakes. That's how we all improve, and we are happy to help others learn.

Being an open source contributor doesn't just mean writing code, either. You can
help out by writing documentation, tests, or even giving feedback about the
project (and yes - that includes giving feedback about the contribution
process). Some of these contributions may be the most valuable to the project as
a whole, because you're coming to the project with fresh eyes, so you can see
the errors and assumptions that seasoned contributors have glossed over.

*This disclaimer was originally written by*
`Adrienne Lowe <https://github.com/adriennefriend>`_ for a
`PyCon talk <https://www.youtube.com/watch?v=6Uj746j9Heo>`_, and was adapted by
dust_extinction based on its use in the README file for the
`MetPy project <https://github.com/Unidata/MetPy>`_.

License
-------

This project is Copyright (c) Karl Gordon and Kristen Larson and licensed under
the terms of the BSD 3-Clause license. This package is based upon
the `Astropy package template <https://github.com/astropy/package-template>`_
which is licensed under the BSD 3-clause licence. See the licenses folder for
more information.

.. _AstroPy: https://www.astropy.org/
.. _contributing: https://docs.astropy.org/en/stable/index.html#contributing
.. _developer: https://docs.astropy.org/en/stable/index.html#developer-documentation
.. _Astropy Code of Conduct:  https://www.astropy.org/about.html#codeofconduct
